@@ -6,7 +6,7 @@ import os
 from pathlib import Path
 from black import format_str, FileMode
 import edgedb
-from pydantic import BaseModel
+from pydantic import BaseModel, parse_raw_as
 from devtools import debug
 from .introspection import (
     introspect_objects,
@@ -47,6 +47,7 @@ class DBConfig(BaseModel):
     password: str
     port: int = 5656
     tls_security: TLSSecurity
+    copy_config: str = None
     hydrate: bool = False
     nodes: T.Dict[str, NodeConfig] = dict()
 
@@ -591,8 +592,7 @@ def get_nodes_to_hydrate(db_config: DBConfig) -> T.Set[str]:
     return node_names
 
 
-async def build_enums_from_config(db_config_d: dict, include_strawberry: bool) -> str:
-    db_config = DBConfig.parse_obj(db_config_d)
+async def build_enums_from_config(db_config: DBConfig, include_strawberry: bool) -> str:
     client = edgedb.create_async_client(
         tls_security=db_config.tls_security,
         host=db_config.host,
@@ -607,12 +607,11 @@ async def build_enums_from_config(db_config_d: dict, include_strawberry: bool) -
 
 
 async def build_from_config(
-    db_config_d: dict,
+    db_config: DBConfig,
     enums_module: str,
     hydrate: bool = False,
     dehydrate: bool = False,
 ) -> str:
-    db_config = DBConfig.parse_obj(db_config_d)
     client = edgedb.create_async_client(
         tls_security=db_config.tls_security,
         host=db_config.host,
@@ -647,24 +646,31 @@ async def generate(
     config_path: Path, output_path: Path, include_strawberry: bool = False
 ) -> None:
     validate_output_path(output_path)
-    for db_name, db_config_d in json.loads(open(config_path).read()).items():
+    all_config_json_str = open(config_path).read()
+    all_config_d = parse_raw_as(T.Dict[str, DBConfig], all_config_json_str)
+    for db_name, db_config in all_config_d.items():
+        if db_config.copy_config:
+            db_config_to_copy = all_config_d[db_config.copy_config]
+            db_config.hydrate = db_config_to_copy.hydrate
+            db_config.nodes = db_config_to_copy.nodes
+
         # first build enums folder
         enums_s = await build_enums_from_config(
-            db_config_d=db_config_d, include_strawberry=include_strawberry
+            db_config=db_config, include_strawberry=include_strawberry
         )
         enums_module = f"{db_name}_enums"
         open(output_path / f"{enums_module}.py", "w").write(enums_s)
-        hydrate = db_config_d.get("hydrate", False)
+        hydrate = db_config.hydrate
         # must include strawberry types in both for circular dependency reasons
         s = await build_from_config(
-            db_config_d=db_config_d,
+            db_config=db_config,
             dehydrate=hydrate,
             enums_module=enums_module,
         )
         open(output_path / f"{db_name}.py", "w").write(s)
         if hydrate:
             s = await build_from_config(
-                db_config_d=db_config_d,
+                db_config=db_config,
                 hydrate=True,
                 enums_module=enums_module,
             )
