@@ -109,6 +109,23 @@ def basemodel_to_str(
 def resolver_equal_or_better(
     resolver_a: "ResolverType", resolver_b: "ResolverType"
 ) -> bool:
+    # TODO must compare variables as well
+    a_nested_vars = resolver_a._get_nested_query_variables()
+    b_nested_vars = resolver_b._get_nested_query_variables()
+    if a_nested_vars != b_nested_vars:
+        # if b has any vars a does not have
+        if len(set(b_nested_vars.keys()) - set(a_nested_vars.keys())) > 0:
+            return False
+        for k, v in a_nested_vars.items():
+            if k not in b_nested_vars:
+                # continue because this will be picked up in the filters if it is important
+                continue
+            if b_nested_vars[k] != v:
+                print(
+                    f"{k=}, {b_nested_vars[k]=} is not equal to {v=} so returning false"
+                )
+                return False
+
     if resolver_a.to_str() == resolver_b.to_str():
         return True
     if resolver_a.all_filters_str() != resolver_b.all_filters_str():
